@@ -23,7 +23,7 @@ impl<'a> Default for BunConfig<'a> {
         BunConfig {
             format: "via [$symbol($version )]($style)",
             version_format: "v${raw}",
-            symbol: "🍞 ",
+            symbol: "🥟 ",
             style: "bold red",
             disabled: false,
             detect_extensions: vec![],
