@@ -1,7 +1,11 @@
 use serde::{Deserialize, Serialize};
 
 #[derive(Clone, Deserialize, Serialize)]
-#[cfg_attr(feature = "config-schema", derive(schemars::JsonSchema))]
+#[cfg_attr(
+    feature = "config-schema",
+    derive(schemars::JsonSchema),
+    schemars(deny_unknown_fields)
+)]
 #[serde(default)]
 pub struct DenoConfig<'a> {
     pub format: &'a str,
@@ -26,6 +30,7 @@ impl<'a> Default for DenoConfig<'a> {
             detect_files: vec![
                 "deno.json",
                 "deno.jsonc",
+                "deno.lock",
                 "mod.ts",
                 "deps.ts",
                 "mod.js",
