@@ -15,6 +15,7 @@ pub struct GcloudConfig<'a> {
     pub disabled: bool,
     pub region_aliases: HashMap<String, &'a str>,
     pub project_aliases: HashMap<String, &'a str>,
+    pub detect_env_vars: Vec<&'a str>,
 }
 
 impl<'a> Default for GcloudConfig<'a> {
@@ -26,6 +27,7 @@ impl<'a> Default for GcloudConfig<'a> {
             disabled: false,
             region_aliases: HashMap::new(),
             project_aliases: HashMap::new(),
+            detect_env_vars: vec![],
         }
     }
 }
