@@ -125,7 +125,7 @@ pub fn get_prompt(context: Context) -> String {
     // color sequences for this specific shell
     let shell_wrapped_output =
         wrap_colorseq_for_shell(AnsiStrings(&module_strings).to_string(), context.shell);
-    write!(buf, "{}", shell_wrapped_output).unwrap();
+    write!(buf, "{shell_wrapped_output}").unwrap();
 
     if context.target == Target::Right {
         // right prompts generally do not allow newlines
